<?php

namespace File\File\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use File\File\Interfaces\ImageRepositoryInterface;

class ImagePublicController extends BaseController
{
    // use ImageWorkflow;

    /**
     * Constructor.
     *
     * @param type \File\Image\Interfaces\ImageRepositoryInterface $image
     *
     * @return type
     */
    public function __construct(ImageRepositoryInterface $image)
    {
        $this->repository = $image;
        parent::__construct();
    }

    /**
     * Show image's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $images = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        return $this->theme->of('file::public.image.index', compact('images'))->render();
    }

    /**
     * Show image.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $image = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('file::public.image.show', compact('image'))->render();
    }

}
