<?php

namespace File\File\Http\Controllers;
use Litepie\File\Http\Requests\ImageRequest;
use Litepie\File\Models\Image;

trait ImageWorkflow {
	
    /**
     * Workflow controller function for image.
     *
     * @param Model   $image
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ImageRequest $request, Image $image, $step)
    {

        try {

            $image->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('file::image.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/image/image/' . $image->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/image/image/' . $image->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for image.
     *
     * @param Model   $image
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Image $image, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $image->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('file::image.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('file::admin.image.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('file::admin.image.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('file::admin.image.message', $data)->render();

        }

    }
}