<?php

namespace File\File\Policies;

use App\User;
use File\File\Models\Image;

class ImagePolicy
{

    /**
     * Determine if the given user can view the image.
     *
     * @param User $user
     * @param Image $image
     *
     * @return bool
     */
    public function view(User $user, Image $image)
    {
        if ($user->canDo('file.image.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $image->user_id;
    }

    /**
     * Determine if the given user can create a image.
     *
     * @param User $user
     * @param Image $image
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('file.image.create');
    }

    /**
     * Determine if the given user can update the given image.
     *
     * @param User $user
     * @param Image $image
     *
     * @return bool
     */
    public function update(User $user, Image $image)
    {
        if ($user->canDo('file.image.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $image->user_id;
    }

    /**
     * Determine if the given user can delete the given image.
     *
     * @param User $user
     * @param Image $image
     *
     * @return bool
     */
    public function destroy(User $user, Image $image)
    {
        if ($user->canDo('file.image.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $image->user_id;
    }

    /**
     * Determine if the given user can verify the given image.
     *
     * @param User $user
     * @param Image $image
     *
     * @return bool
     */
    public function verify(User $user, Image $image)
    {
        if ($user->canDo('file.image.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('file.image.verify') 
        && $user->is('manager')
        && $image->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given image.
     *
     * @param User $user
     * @param Image $image
     *
     * @return bool
     */
    public function approve(User $user, Image $image)
    {
        if ($user->canDo('file.image.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
