<?php

namespace File\File\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use File\File\Models\File;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'File\File\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/file/image/*')) {
            Route::bind('image', function ($image) {
                $imagerepo = $this->app->make('\File\File\Interfaces\ImageRepositoryInterface');
                return $imagerepo->findorNew($image);
            });
        }if (Request::is('*/file/video/*')) {
            Route::bind('video', function ($video) {
                $videorepo = $this->app->make('\File\File\Interfaces\VideoRepositoryInterface');
                return $videorepo->findorNew($video);
            });
        }if (Request::is('*/file/auteur/*')) {
            Route::bind('auteur', function ($auteur) {
                $auteurrepo = $this->app->make('\File\File\Interfaces\AuteurRepositoryInterface');
                return $auteurrepo->findorNew($auteur);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        // $this->mapApiRoutes();

        //
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        Route::group([
            'middleware' => 'web',
            'namespace' => $this->namespace,
            'prefix' => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace' => $this->namespace . '\Api',
            'prefix' => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../../../routes/api.php');
        });
    }
}
