<?php

namespace File\File\Workflow;

use File\File\Models\Image;
use Validator;

class ImageValidator
{

    /**
     * Determine if the given image is valid for complete status.
     *
     * @param Image $image
     *
     * @return bool / Validator
     */
    public function complete(Image $image)
    {
        return Validator::make($image->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given image is valid for verify status.
     *
     * @param Image $image
     *
     * @return bool / Validator
     */
    public function verify(Image $image)
    {
        return Validator::make($image->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given image is valid for approve status.
     *
     * @param Image $image
     *
     * @return bool / Validator
     */
    public function approve(Image $image)
    {
        return Validator::make($image->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given image is valid for publish status.
     *
     * @param Image $image
     *
     * @return bool / Validator
     */
    public function publish(Image $image)
    {
        return Validator::make($image->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given image is valid for archive status.
     *
     * @param Image $image
     *
     * @return bool / Validator
     */
    public function archive(Image $image)
    {
        return Validator::make($image->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given image is valid for unpublish status.
     *
     * @param Image $image
     *
     * @return bool / Validator
     */
    public function unpublish(Image $image)
    {
        return Validator::make($image->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
